# -*- coding: utf-8 -*-
"""
@Time : 2022/3/30 11:10
@Author : YarnBlue
@description :
@File : configs.py
"""
USERNAME = 'username'
PASSWORD = 'password'
HOST = 'https://rr.hanchenshop.com'
DELAY = 0.5
